#ifndef __PCE_INPUT_MOUSE_H
#define __PCE_INPUT_MOUSE_H

namespace MDFN_IEN_PCE
{

MDFN_HIDE extern const IDIISG PCE_MouseIDII;

PCE_Input_Device *PCEINPUT_MakeMouse(void);

};

#endif
